==> piwigo-2.1.5.tbz: www/piwigo/plugins/LocalFilesEditor/language/lv_LV/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokala konfiguracija';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Veidnes';
$lang['locfiledit_onglet_lang'] = 'Valodas';
$lang['locfiledit_onglet_plug'] = 'Personas spraudni';
$lang['locfiledit_cant_save'] = ' Esošais fails nav ierakstams. Parbaudit vai mape "include/" ir ar rakstišanas tiesibam (chmod).';
$lang['locfiledit_newfile'] = 'Fails neeksiste, tas tiks izveidots izmantojot LocalFiles Editor';
$lang['locfiledit_save_config'] = ' Fails ierakstits sekmigi.';
$lang['locfiledit_show_default'] = ' Paradit izvelnes failu: ';
$lang['locfiledit_save_bak'] = ' Rezerves kopija tiks izveidota veicot saglabašanu.';
$lang['locfiledit_saved_bak'] = 'Rezerves kopija izveidota par (%s)';
$lang['locfiledit_save_file'] = ' Saglabat failu';
$lang['locfiledit_choose_file'] = ' Izveleties failu ko rediget';
$lang['locfiledit_edit'] = 'Rediget';
$lang['locfiledit_restore'] = 'Atjaunot rezerves kopiju';
$lang['locfiledit_restore_confirm'] = 'Ludzu apstprinat?
Atjaunošana nebus iespejama lidz nakamai saglabašanai.';
$lang['locfiledit_bak_loaded1'] = 'Rezerves kopija ieladeta.';
$lang['locfiledit_bak_loaded2'] = 'Jums jasaglaba fails lai to atjaunotu.';
$lang['locfiledit_syntax_error'] = 'Sintakses kluda! Failu nav iespejams saglabat.';
$lang['locfiledit_enable_editarea'] = 'Iespejot Redigešanas apgabalu';
$lang['locfiledit_disable_editarea'] = 'Atspejot Redigešanas apgabalu';
$lang['locfiledit_new_tpl'] = 'Izveidot jaunu failu';
$lang['locfiledit_new_filename'] = 'Faila nosaukums';
$lang['locfiledit_model'] = 'Modelis';
$lang['locfiledit_empty_page'] = 'Tukša lapa';
$lang['locfiledit_parent_directory'] = 'Pamatmape';
$lang['locfiledit_filename_error'] = 'Aizliegti simboli nosaukuma.';
$lang['locfiledit_file_already_exists'] = 'Fails jau eksiste.';
$lang['locfiledit_model_error'] = 'Jums jaizvelas modelis.';
$lang['locfiledit_empty_filename'] = 'Jums jaieraksta faila nosaukums.';
$lang['locfiledit_webmaster_only'] = 'Tikai webmasters var izveidot un modificet lokalos failus.';

?>

==> piwigo-2.3.3.tbz: www/piwigo/plugins/LocalFilesEditor/language/lv_LV/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokala konfiguracija';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Veidnes';
$lang['locfiledit_onglet_lang'] = 'Valodas';
$lang['locfiledit_onglet_plug'] = 'Personas spraudni';
$lang['locfiledit_cant_save'] = ' Esošais fails nav ierakstams. Parbaudit vai mape "local/" ir ar rakstišanas tiesibam (chmod).';
$lang['locfiledit_newfile'] = 'Fails neeksiste, tas tiks izveidots izmantojot LocalFiles Editor';
$lang['locfiledit_save_config'] = ' Fails ierakstits sekmigi.';
$lang['locfiledit_show_default'] = ' Paradit izvelnes failu: ';
$lang['locfiledit_save_bak'] = ' Rezerves kopija tiks izveidota veicot saglabašanu.';
$lang['locfiledit_saved_bak'] = 'Rezerves kopija izveidota par (%s)';
$lang['locfiledit_save_file'] = ' Saglabat failu';
$lang['locfiledit_choose_file'] = ' Izveleties failu ko rediget';
$lang['locfiledit_edit'] = 'Rediget';
$lang['locfiledit_restore'] = 'Atjaunot rezerves kopiju';
$lang['locfiledit_restore_confirm'] = 'Ludzu apstprinat?
Atjaunošana nebus iespejama lidz nakamai saglabašanai.';
$lang['locfiledit_bak_loaded1'] = 'Rezerves kopija ieladeta.';
$lang['locfiledit_bak_loaded2'] = 'Jums jasaglaba fails lai to atjaunotu.';
$lang['locfiledit_syntax_error'] = 'Sintakses kluda! Failu nav iespejams saglabat.';
$lang['locfiledit_new_tpl'] = 'Izveidot jaunu failu';
$lang['locfiledit_new_filename'] = 'Faila nosaukums';
$lang['locfiledit_model'] = 'Modelis';
$lang['locfiledit_empty_page'] = 'Tukša lapa';
$lang['locfiledit_parent_directory'] = 'Pamatmape';
$lang['locfiledit_filename_error'] = 'Aizliegti simboli nosaukuma.';
$lang['locfiledit_file_already_exists'] = 'Fails jau eksiste.';
$lang['locfiledit_model_error'] = 'Jums jaizvelas modelis.';
$lang['locfiledit_empty_filename'] = 'Jums jaieraksta faila nosaukums.';
$lang['locfiledit_webmaster_only'] = 'Tikai webmasters var izveidot un modificet lokalos failus.';
?>
